==> qt5-script-debuginfo-5.4.2-1.tar.xz: usr/src/debug/qt5-script-5.4.2-1/examples/script/defaultprototypes/.rcc/qrc_defaultprototypes.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.4.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-script/qt5-script-5.4.2-1.x86_64/src/qtscript-opensource-src-5.4.2/examples/script/defaultprototypes/code.js
  0x0,0x0,0x1,0x71,
  0x2f,
  0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,
  0x74,0x2e,0x61,0x64,0x64,0x49,0x74,0x65,0x6d,0x28,0x22,0x52,0x65,0x64,0x22,0x29,
  0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,0x61,0x64,0x64,
  0x49,0x74,0x65,0x6d,0x28,0x22,0x42,0x6c,0x75,0x65,0x22,0x29,0x3b,0xa,0x6c,0x69,
  0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,0x61,0x64,0x64,0x49,0x74,0x65,0x6d,
  0x28,0x22,0x47,0x72,0x65,0x65,0x6e,0x22,0x29,0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,
  0x69,0x64,0x67,0x65,0x74,0x2e,0x61,0x64,0x64,0x49,0x74,0x65,0x6d,0x28,0x22,0x43,
  0x79,0x61,0x6e,0x22,0x29,0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,
  0x74,0x2e,0x61,0x64,0x64,0x49,0x74,0x65,0x6d,0x28,0x22,0x59,0x65,0x6c,0x6c,0x6f,
  0x77,0x22,0x29,0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,
  0x61,0x64,0x64,0x49,0x74,0x65,0x6d,0x28,0x22,0x50,0x75,0x72,0x70,0x6c,0x65,0x22,
  0x29,0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,0x61,0x64,
  0x64,0x49,0x74,0x65,0x6d,0x73,0x28,0x5b,0x22,0x4f,0x72,0x61,0x6e,0x67,0x65,0x22,
  0x2c,0x20,0x22,0x47,0x72,0x61,0x79,0x22,0x5d,0x29,0x3b,0xa,0x2f,0x2f,0x21,0x20,
  0x5b,0x30,0x5d,0xa,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x31,0x5d,0xa,0x6c,0x69,0x73,
  0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,0x63,0x75,0x72,0x72,0x65,0x6e,0x74,0x49,
  0x74,0x65,0x6d,0x43,0x68,0x61,0x6e,0x67,0x65,0x64,0x2e,0x63,0x6f,0x6e,0x6e,0x65,
  0x63,0x74,0x28,0xa,0x20,0x20,0x20,0x20,0x66,0x75,0x6e,0x63,0x74,0x69,0x6f,0x6e,
  0x28,0x69,0x74,0x65,0x6d,0x29,0xa,0x20,0x20,0x20,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,
  0x73,0x65,0x74,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x43,0x6f,0x6c,
  0x6f,0x72,0x28,0x69,0x74,0x65,0x6d,0x2e,0x74,0x65,0x78,0x74,0x29,0x3b,0xa,0x20,
  0x20,0x20,0x20,0x7d,0xa,0x29,0x3b,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x31,0x5d,0xa,
  
  
};

static const unsigned char qt_resource_name[] = {
  // code.js
  0x0,0x7,
  0xa,0x5a,0x85,0xd3,
  0x0,0x63,
  0x0,0x6f,0x0,0x64,0x0,0x65,0x0,0x2e,0x0,0x6a,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/code.js
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_defaultprototypes)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_defaultprototypes)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_defaultprototypes)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_defaultprototypes)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_defaultprototypes)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_defaultprototypes)(); }
   } dummy;
}

==> qt5-script-debuginfo-5.5.1-1.tar.xz: usr/src/debug/qt5-script-5.5.1-1/examples/script/defaultprototypes/.rcc/qrc_defaultprototypes.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.5.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-script/qt5-script-5.5.1-1.i686/src/qtscript-opensource-src-5.5.1/examples/script/defaultprototypes/code.js
  0x0,0x0,0x1,0x71,
  0x2f,
  0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,
  0x74,0x2e,0x61,0x64,0x64,0x49,0x74,0x65,0x6d,0x28,0x22,0x52,0x65,0x64,0x22,0x29,
  0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,0x61,0x64,0x64,
  0x49,0x74,0x65,0x6d,0x28,0x22,0x42,0x6c,0x75,0x65,0x22,0x29,0x3b,0xa,0x6c,0x69,
  0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,0x61,0x64,0x64,0x49,0x74,0x65,0x6d,
  0x28,0x22,0x47,0x72,0x65,0x65,0x6e,0x22,0x29,0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,
  0x69,0x64,0x67,0x65,0x74,0x2e,0x61,0x64,0x64,0x49,0x74,0x65,0x6d,0x28,0x22,0x43,
  0x79,0x61,0x6e,0x22,0x29,0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,
  0x74,0x2e,0x61,0x64,0x64,0x49,0x74,0x65,0x6d,0x28,0x22,0x59,0x65,0x6c,0x6c,0x6f,
  0x77,0x22,0x29,0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,
  0x61,0x64,0x64,0x49,0x74,0x65,0x6d,0x28,0x22,0x50,0x75,0x72,0x70,0x6c,0x65,0x22,
  0x29,0x3b,0xa,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,0x61,0x64,
  0x64,0x49,0x74,0x65,0x6d,0x73,0x28,0x5b,0x22,0x4f,0x72,0x61,0x6e,0x67,0x65,0x22,
  0x2c,0x20,0x22,0x47,0x72,0x61,0x79,0x22,0x5d,0x29,0x3b,0xa,0x2f,0x2f,0x21,0x20,
  0x5b,0x30,0x5d,0xa,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x31,0x5d,0xa,0x6c,0x69,0x73,
  0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,0x63,0x75,0x72,0x72,0x65,0x6e,0x74,0x49,
  0x74,0x65,0x6d,0x43,0x68,0x61,0x6e,0x67,0x65,0x64,0x2e,0x63,0x6f,0x6e,0x6e,0x65,
  0x63,0x74,0x28,0xa,0x20,0x20,0x20,0x20,0x66,0x75,0x6e,0x63,0x74,0x69,0x6f,0x6e,
  0x28,0x69,0x74,0x65,0x6d,0x29,0xa,0x20,0x20,0x20,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x6c,0x69,0x73,0x74,0x57,0x69,0x64,0x67,0x65,0x74,0x2e,
  0x73,0x65,0x74,0x42,0x61,0x63,0x6b,0x67,0x72,0x6f,0x75,0x6e,0x64,0x43,0x6f,0x6c,
  0x6f,0x72,0x28,0x69,0x74,0x65,0x6d,0x2e,0x74,0x65,0x78,0x74,0x29,0x3b,0xa,0x20,
  0x20,0x20,0x20,0x7d,0xa,0x29,0x3b,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x31,0x5d,0xa,
  
  
};

static const unsigned char qt_resource_name[] = {
  // code.js
  0x0,0x7,
  0xa,0x5a,0x85,0xd3,
  0x0,0x63,
  0x0,0x6f,0x0,0x64,0x0,0x65,0x0,0x2e,0x0,0x6a,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/code.js
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_defaultprototypes)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_defaultprototypes)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_defaultprototypes)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_defaultprototypes)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_defaultprototypes)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_defaultprototypes)(); }
   } dummy;
}
